@@ -8,6 +8,8 @@ import setuptools
 import shutil
 
 settings_template = '''
+import os
+
 ADMINS = (
     # ('Your Name', 'your_email@domain.com'),
 )
@@ -15,7 +17,7 @@ ADMINS = (
 MANAGERS = ADMINS
 
 DATABASE_ENGINE = 'sqlite3'    # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
-DATABASE_NAME = ''
+DATABASE_NAME = '%(project)s.db'
 DATABASE_USER = ''             # Not used with sqlite3.
 DATABASE_PASSWORD = ''         # Not used with sqlite3.
 DATABASE_HOST = ''             # Set to empty string for localhost. Not used with sqlite3.
@@ -59,25 +61,39 @@ INSTALLED_APPS = (
     'django.contrib.admin',
 )
 
+TEMPLATE_LOADERS = (
+    'django.template.loaders.filesystem.load_template_source',
+    'django.template.loaders.app_directories.load_template_source',
+)
+
+TEMPLATE_DIRS = (
+    os.path.join(os.path.dirname(__file__), "templates"),
+)
+
+
+from %(project)s.%(settings)s import *
 '''
 
-development_settings = settings_template + '''
+development_settings = '''
 DEBUG=True
 TEMPLATE_DEBUG=DEBUG
 '''
 
 urls_template = '''
-from django.conf.urls.defaults import patterns, include
+from django.conf.urls.defaults import patterns, include, handler500
 from django.conf import settings
 
+handler500 # Pyflakes
+
 urlpatterns = patterns(
     '',
     (r'^admin/', include('django.contrib.admin.urls')),
+    (r'^accounts/login/$', 'django.contrib.auth.views.login'),
 )
 
 if settings.DEBUG:
     urlpatterns += patterns('',
-        (r'^data/(?P<path>.*)$', 'django.views.static.serve', 
+        (r'^media/(?P<path>.*)$', 'django.views.static.serve', 
          {'document_root': settings.MEDIA_ROOT}),
     )
 '''
@@ -94,9 +110,10 @@ class Recipe(object):
         options.setdefault('project', 'project')
         options.setdefault('settings', 'development')
 
-
         options.setdefault('urlconf', 'urls')
-        options.setdefault('media_root', 'media')
+        options.setdefault(
+            'media_root', os.path.abspath(os.path.join(
+                    os.path.dirname(__file__), 'media')))
         options.setdefault('secret', self.generate_secret())
         # set this so the rest of the recipe can expect it to be there
         options.setdefault('pythonpath', '')
@@ -168,6 +185,7 @@ class Recipe(object):
         
         requirements, ws = self.egg.working_set(['djangorecipe'])
 
+        # Create the Django management script
         zc.buildout.easy_install.scripts(
             [(self.options.get('control-script', self.name),
                 'djangorecipe.manage', 'main')],
@@ -175,6 +193,19 @@ class Recipe(object):
             extra_paths = extra_paths,
             arguments= "'settings'")
 
+        # Create the test runner
+        apps = self.options.get('test', '').split()
+        # Only create the testrunner if the user requests it
+        if apps:
+            zc.buildout.easy_install.scripts(
+                [(self.options.get('testrunner', 'test'),
+                  'djangorecipe.test', 'main')],
+                ws, self.options['executable'], self.options['bin-directory'],
+                extra_paths = extra_paths,
+                arguments= "'settings', %s" % ', '.join(
+                    ["'%s'" % app for app in apps]))
+
+
         # Create default settings
         if not os.path.exists(project_dir):
             os.makedirs(project_dir)
@@ -185,7 +216,7 @@ class Recipe(object):
 
         self.create_file(
             os.path.join(project_dir, 'production.py'),
-            settings_template, self.options)
+            '', self.options)
 
         self.create_file(
             os.path.join(project_dir, 'urls.py'),
@@ -193,7 +224,11 @@ class Recipe(object):
 
         self.create_file(
             os.path.join(project_dir, 'settings.py'),
-            'from %(project)s.%(settings)s import *', self.options)
+            settings_template, self.options)
+
+        # Create the media and templates directories for our project
+        os.mkdir(os.path.join(project_dir, 'media'))
+        os.mkdir(os.path.join(project_dir, 'templates'))
 
         # Make the settings dir a Python package so that Django can
         # load the settings from it. It will act like the project dir.
